@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import contextlib
 from copy import deepcopy
 from datetime import timedelta
 import re
@@ -338,8 +339,7 @@ class ODEScenario(Term):
         df = engineer.all().set_index(self.DATE).loc[self._first:self._last, v_converted]
         # Show figure
         if display:
-            plot_kwargs = {"title": title, "y_integer": True, "v": v, "ylabel": "the number of cases"}
-            plot_kwargs.update(kwargs)
+            plot_kwargs = {"title": title, "y_integer": True, "v": v, "ylabel": "the number of cases", **kwargs}
             line_plot(df=df, **plot_kwargs)
         return df
 
@@ -380,11 +380,10 @@ class ODEScenario(Term):
             end_date, name="the second date of @date_range").date(value_range=(start, None), default=df.index.max())
         df = df.loc[start: end]
         if display:
-            ylabel = f"the number of {v_converted[0]} cases"
+            ylabel = f"the number of {v_converted.lower()} cases"
             title = f"{self._location_name}: {ylabel} overt time"
             v = self.to_dynamics(name=ref or list(self._snr_alias.all().keys())[0]).start_dates()[1:]
-            plot_kwargs = {"title": title, "y_integer": True, "v": v, "ylabel": ylabel}
-            plot_kwargs.update(kwargs)
+            plot_kwargs = {"title": title, "y_integer": True, "v": v, "ylabel": ylabel, **kwargs}
             line_plot(df=df, **plot_kwargs)
         return df.convert_dtypes()
 
@@ -418,8 +417,7 @@ class ODEScenario(Term):
             ylabel, h = (self.RT_FULL, 1.0) if param == self.RT else (param, None)
             title = f"{self._location_name}: {ylabel} overt time"
             v = self.to_dynamics(name=ref or list(self._snr_alias.all().keys())[0]).start_dates()[1:]
-            plot_kwargs = {"title": title, "math_scale": False, "v": v, "ylabel": ylabel, "h": h}
-            plot_kwargs.update(kwargs)
+            plot_kwargs = {"title": title, "math_scale": False, "v": v, "ylabel": ylabel, "h": h, **kwargs}
             line_plot(df=df, **plot_kwargs)
         return df.convert_dtypes()
 
@@ -533,7 +531,9 @@ class ODEScenario(Term):
         phase_df = phase_df.loc[
             (phase_df.index[-1]) | (phase_df["end"] < phase_df["end"].shift(periods=-1) - timedelta(days=3))]
         for phase_dict in phase_df.to_dict(orient="records"):
-            self._append(name=name, **phase_dict)
+            with contextlib.suppress(UnExpectedValueRangeError):
+                # Skip when the first new phase is smaller than 3 days
+                self._append(name=name, **phase_dict)
         return self
 
     def represent(self, q, variable, date=None, included=None, excluded=None):
